==> Tnos-2.22-src.tar.gz: map.h <==
#define ALERTMONITOR_OFF	8
#define ALERTMONITOR_VAL	0x01
#define ALLCMD_OFF		17
#define ALLCMD_VAL		0x20
#define ALLSERV_OFF		0
#define ALLSERV_VAL		0x01
#define ALLSESSIONS_OFF		17
#define ALLSESSIONS_VAL		0x80
#define ALTERBID_OFF		4
#define ALTERBID_VAL		0x04
#define ARCNET_OFF		13
#define ARCNET_VAL		0x08
#define ASKHOME_OFF		4
#define ASKHOME_VAL		0x20
#define ASY_OFF			12
#define ASY_VAL			0x01
#define ATCMD_OFF		16
#define ATCMD_VAL		0x40
#define AUTOROUTE_OFF		9
#define AUTOROUTE_VAL		0x08
#define AXBCSTR_OFF		10
#define AXBCSTR_VAL		0x20
#define AXIP_OFF		10
#define AXIP_VAL		0x01
#define AXNEGOTIATION_OFF	10
#define AXNEGOTIATION_VAL	0x80
#define AXUI_OFF		10
#define AXUI_VAL		0x10
#define BBSEXPORT_OFF		5
#define BBSEXPORT_VAL		0x08
#define BBSIMPORT_OFF		5
#define BBSIMPORT_VAL		0x10
#define BOOTPCLIENT_OFF		13
#define BOOTPCLIENT_VAL		0x40
#define BOOTPSERVER_OFF		11
#define BOOTPSERVER_VAL		0x02
#define BROWSER_OFF		13
#define BROWSER_VAL		0x80
#define CALLBOOK_OFF		12
#define CALLBOOK_VAL		0x80
#define CALLCLI_OFF		12
#define CALLCLI_VAL		0x40
#define CALLSERVER_OFF		12
#define CALLSERVER_VAL		0x08
#define CATALOG_OFF		15
#define CATALOG_VAL		0x02
#define CONVERS_OFF		2
#define CONVERS_VAL		0x80
#define CRONTAB_OFF		1
#define CRONTAB_VAL		0x10
#define DELEGATE_OFF		4
#define DELEGATE_VAL		0x80
#define DIALER_OFF		6
#define DIALER_VAL		0x01
#define DOS_GETFILEATTR_OFF	16
#define DOS_GETFILEATTR_VAL	0x04
#define DRSI_OFF		14
#define DRSI_VAL		0x10
#define DSERVER_OFF		0
#define DSERVER_VAL		0x20
#define EAGLE_OFF		14
#define EAGLE_VAL		0x80
#define EDITHEADERS_OFF		6
#define EDITHEADERS_VAL		0x40
#define ENCAP_OFF		9
#define ENCAP_VAL		0x10
#define ESCAPE_OFF		16
#define ESCAPE_VAL		0x10
#define EXPIRY_OFF		4
#define EXPIRY_VAL		0x01
#define FBBCMP_OFF		5
#define FBBCMP_VAL		0x40
#define FBBFWD_OFF		5
#define FBBFWD_VAL		0x80
#define FIFOSERVER_OFF		1
#define FIFOSERVER_VAL		0x02
#define FILECMDS_OFF		3
#define FILECMDS_VAL		0x40
#define FOQ_CMDS_OFF		3
#define FOQ_CMDS_VAL		0x08
#define FORTH_OFF		17
#define FORTH_VAL		0x08
#define FTPTDISC_OFF		17
#define FTPTDISC_VAL		0x40
#define GATECMDS_OFF		3
#define GATECMDS_VAL		0x20
#define GPS_OFF			2
#define GPS_VAL			0x10
#define HAPN_OFF		13
#define HAPN_VAL		0x01
#define HOLDMODS_OFF		8
#define HOLDMODS_VAL		0x08
#define HOLDMONITOR_OFF		8
#define HOLDMONITOR_VAL		0x02
#define HOPCHECK_OFF		9
#define HOPCHECK_VAL		0x04
#define HOPPER_OFF		8
#define HOPPER_VAL		0x04
#define HS_OFF			13
#define HS_VAL			0x02
#define HTTPPBBS_OFF		1
#define HTTPPBBS_VAL		0x40
#define HTTP_OFF		1
#define HTTP_VAL		0x80
#define IPACCESS_OFF		7
#define IPACCESS_VAL		0x02
#define ISUNIX_OFF		0
#define ISUNIX_VAL		0x80
#define KISS_OFF		12
#define KISS_VAL		0x04
#define LOCK_OFF		16
#define LOCK_VAL		0x20
#define LOG_GMT_TZ_OFF		5
#define LOG_GMT_TZ_VAL		0x02
#define LOOKSESSION_OFF		9
#define LOOKSESSION_VAL		0x02
#define LZW_OFF			16
#define LZW_VAL			0x80
#define MAILBOX_OFF		3
#define MAILBOX_VAL		0x80
#define MAILCMDS_OFF		3
#define MAILCMDS_VAL		0x04
#define MAILFILTER_OFF		8
#define MAILFILTER_VAL		0x10
#define MAILFOR_OFF		3
#define MAILFOR_VAL		0x01
#define MBFWD_OFF		4
#define MBFWD_VAL		0x40
#define MBXTDISC_OFF		4
#define MBXTDISC_VAL		0x02
#define MESSAGESERVER_OFF	13
#define MESSAGESERVER_VAL	0x20
#define MONITOR_OFF		17
#define MONITOR_VAL		0x10
#define NETROM_OFF		10
#define NETROM_VAL		0x04
#define NNTPFILTER_OFF		2
#define NNTPFILTER_VAL		0x08
#define NNTPS_OFF		2
#define NNTPS_VAL		0x40
#define NNTP_OFF		2
#define NNTP_VAL		0x20
#define NR4TDISC_OFF		10
#define NR4TDISC_VAL		0x02
#define NRS_OFF			10
#define NRS_VAL			0x08
#define PACKET_OFF		14
#define PACKET_VAL		0x40
#define PC100_OFF		14
#define PC100_VAL		0x20
#define PC_EC_OFF		13
#define PC_EC_VAL		0x04
#define PING_SECURE_OFF		3
#define PING_SECURE_VAL		0x10
#define PI_OFF			14
#define PI_VAL			0x04
#define POLLEDKISS_OFF		12
#define POLLEDKISS_VAL		0x02
#define POOLED_OFF		16
#define POOLED_VAL		0x01
#define POP2CLIENT_OFF		7
#define POP2CLIENT_VAL		0x04
#define POP2SERVER_OFF		7
#define POP2SERVER_VAL		0x08
#define POP3CLIENT_OFF		7
#define POP3CLIENT_VAL		0x10
#define POP3SERVER_OFF		7
#define POP3SERVER_VAL		0x20
#define POP_OFF			7
#define POP_VAL			0x80
#define PPP_OFF			6
#define PPP_VAL			0x08
#define QRZCALLB_OFF		12
#define QRZCALLB_VAL		0x20
#define RARP_OFF		9
#define RARP_VAL		0x20
#define RDATE_OFF		0
#define RDATE_VAL		0x08
#define REJECT_OFF		5
#define REJECT_VAL		0x04
#define REQSVR_OFF		8
#define REQSVR_VAL		0x40
#define RIP_OFF			9
#define RIP_VAL			0x80
#define RLINE_OFF		4
#define RLINE_VAL		0x08
#define RLOGINCLI_OFF		2
#define RLOGINCLI_VAL		0x02
#define RLOGINSERV_OFF		2
#define RLOGINSERV_VAL		0x04
#define RMAIL_OFF		8
#define RMAIL_VAL		0x80
#define RSPF_OFF		9
#define RSPF_VAL		0x40
#define RXECHO_OFF		9
#define RXECHO_VAL		0x01
#define SAMCALLB_OFF		12
#define SAMCALLB_VAL		0x10
#define SCC_OFF			14
#define SCC_VAL			0x08
#define SCREENSAVER_OFF		13
#define SCREENSAVER_VAL		0x10
#define SCRIPTING_OFF		15
#define SCRIPTING_VAL		0x04
#define SERVERS_OFF		0
#define SERVERS_VAL		0x40
#define SETPSINFO_OFF		15
#define SETPSINFO_VAL		0x08
#define SHELL_OFF		16
#define SHELL_VAL		0x08
#define SLFP_OFF		14
#define SLFP_VAL		0x02
#define SLIP_OFF		6
#define SLIP_VAL		0x04
#define SM_CURSES_OFF		15
#define SM_CURSES_VAL		0x40
#define SM_DUMB_OFF		14
#define SM_DUMB_VAL		0x01
#define SM_RAW_OFF		15
#define SM_RAW_VAL		0x80
#define SOUNDS_OFF		15
#define SOUNDS_VAL		0x10
#define SQL_OFF			1
#define SQL_VAL			0x04
#define STATS_AREA_OFF		11
#define STATS_AREA_VAL		0x10
#define STATS_FWD_OFF		11
#define STATS_FWD_VAL		0x08
#define STATS_MSG_OFF		11
#define STATS_MSG_VAL		0x20
#define STATS_OFF		11
#define STATS_VAL		0x80
#define STATS_TFC_OFF		11
#define STATS_TFC_VAL		0x04
#define STATS_USE_OFF		11
#define STATS_USE_VAL		0x40
#define STRICT_CALL_OFF		16
#define STRICT_CALL_VAL		0x02
#define STRICT_HTTPCALL_OFF	1
#define STRICT_HTTPCALL_VAL	0x20
#define TCPACCESS_OFF		7
#define TCPACCESS_VAL		0x01
#define TCPGATE_OFF		1
#define TCPGATE_VAL		0x08
#define TERMSERVER_OFF		0
#define TERMSERVER_VAL		0x02
#define TIPMAIL_OFF		6
#define TIPMAIL_VAL		0x20
#define TRACESERVER_OFF		1
#define TRACESERVER_VAL		0x01
#define TRACE_OFF		2
#define TRACE_VAL		0x01
#define TRANSLATE_OFF		8
#define TRANSLATE_VAL		0x20
#define TSCRIPTSERVER_OFF	11
#define TSCRIPTSERVER_VAL	0x01
#define TTYCALL_OFF		10
#define TTYCALL_VAL		0x40
#define TUTOR_OFF		0
#define TUTOR_VAL		0x10
#define UNIX_SOCKETS_OFF	15
#define UNIX_SOCKETS_VAL	0x20
#define USEPOP3_OFF		7
#define USEPOP3_VAL		0x40
#define USERLOG_OFF		3
#define USERLOG_VAL		0x02
#define USE_TZOFFSET_OFF	5
#define USE_TZOFFSET_VAL	0x01
#define VERSION_ON_FILE_OFF	15
#define VERSION_ON_FILE_VAL	0x01
#define VJCOMPRESS_OFF		6
#define VJCOMPRESS_VAL		0x02
#define WPAGES_OFF		4
#define WPAGES_VAL		0x10
#define XFWD_OFF		5
#define XFWD_VAL		0x20
#define XMODEM_OFF		6
#define XMODEM_VAL		0x10
#define XSERVER_OFF		0
#define XSERVER_VAL		0x04


#define UNUSED_OFF		6
#define UNUSED_VAL		0x80

#define MAPLENGTH 18

==> Tnos-2.30-src.tar.gz: map.h <==
#define ALERTMONITOR_OFF	8
#define ALERTMONITOR_VAL	0x01
#define ALLCMD_OFF		17
#define ALLCMD_VAL		0x20
#define ALLSERV_OFF		0
#define ALLSERV_VAL		0x01
#define ALLSESSIONS_OFF		17
#define ALLSESSIONS_VAL		0x80
#define ALTERBID_OFF		4
#define ALTERBID_VAL		0x04
#define ARCNET_OFF		13
#define ARCNET_VAL		0x08
#define ASKHOME_OFF		4
#define ASKHOME_VAL		0x20
#define ASY_OFF			12
#define ASY_VAL			0x01
#define ATCMD_OFF		16
#define ATCMD_VAL		0x40
#define AUTOROUTE_OFF		9
#define AUTOROUTE_VAL		0x08
#define AXBCSTR_OFF		10
#define AXBCSTR_VAL		0x20
#define AXIP_OFF		10
#define AXIP_VAL		0x01
#define AXUI_OFF		10
#define AXUI_VAL		0x10
#define BBSEXPORT_OFF		5
#define BBSEXPORT_VAL		0x08
#define BBSIMPORT_OFF		5
#define BBSIMPORT_VAL		0x10
#define BOOTPCLIENT_OFF		13
#define BOOTPCLIENT_VAL		0x40
#define BOOTPSERVER_OFF		11
#define BOOTPSERVER_VAL		0x02
#define BROWSER_OFF		13
#define BROWSER_VAL		0x80
#define CALLBOOK_OFF		12
#define CALLBOOK_VAL		0x80
#define CALLCLI_OFF		12
#define CALLCLI_VAL		0x40
#define CALLSERVER_OFF		12
#define CALLSERVER_VAL		0x08
#define CATALOG_OFF		15
#define CATALOG_VAL		0x02
#define CONVERS_OFF		2
#define CONVERS_VAL		0x80
#define CRONTAB_OFF		1
#define CRONTAB_VAL		0x10
#define DELEGATE_OFF		4
#define DELEGATE_VAL		0x80
#define DIALER_OFF		6
#define DIALER_VAL		0x01
#define DOS_GETFILEATTR_OFF	16
#define DOS_GETFILEATTR_VAL	0x04
#define DRSI_OFF		14
#define DRSI_VAL		0x10
#define DSERVER_OFF		0
#define DSERVER_VAL		0x20
#define EAGLE_OFF		14
#define EAGLE_VAL		0x80
#define EDITHEADERS_OFF		6
#define EDITHEADERS_VAL		0x40
#define ENCAP_OFF		9
#define ENCAP_VAL		0x10
#define ESCAPE_OFF		16
#define ESCAPE_VAL		0x10
#define EXPIRY_OFF		4
#define EXPIRY_VAL		0x01
#define FBBCMP_OFF		5
#define FBBCMP_VAL		0x40
#define FBBFWD_OFF		5
#define FBBFWD_VAL		0x80
#define FIFOSERVER_OFF		1
#define FIFOSERVER_VAL		0x02
#define FILECMDS_OFF		3
#define FILECMDS_VAL		0x40
#define FOQ_CMDS_OFF		3
#define FOQ_CMDS_VAL		0x08
#define FORTH_OFF		17
#define FORTH_VAL		0x08
#define FTPTDISC_OFF		17
#define FTPTDISC_VAL		0x40
#define GATECMDS_OFF		3
#define GATECMDS_VAL		0x20
#define GPS_OFF			2
#define GPS_VAL			0x10
#define HAPN_OFF		13
#define HAPN_VAL		0x01
#define HOLDMODS_OFF		8
#define HOLDMODS_VAL		0x08
#define HOLDMONITOR_OFF		8
#define HOLDMONITOR_VAL		0x02
#define HOPCHECK_OFF		9
#define HOPCHECK_VAL		0x04
#define HOPPER_OFF		8
#define HOPPER_VAL		0x04
#define HS_OFF			13
#define HS_VAL			0x02
#define HTTPPBBS_OFF		1
#define HTTPPBBS_VAL		0x40
#define HTTP_OFF		1
#define HTTP_VAL		0x80
#define IPACCESS_OFF		7
#define IPACCESS_VAL		0x02
#define ISUNIX_OFF		0
#define ISUNIX_VAL		0x80
#define KISS_OFF		12
#define KISS_VAL		0x04
#define LOCK_OFF		16
#define LOCK_VAL		0x20
#define LOG_GMT_TZ_OFF		5
#define LOG_GMT_TZ_VAL		0x02
#define LOOKSESSION_OFF		9
#define LOOKSESSION_VAL		0x02
#define LZW_OFF			16
#define LZW_VAL			0x80
#define MAILBOX_OFF		3
#define MAILBOX_VAL		0x80
#define MAILCMDS_OFF		3
#define MAILCMDS_VAL		0x04
#define MAILFILTER_OFF		8
#define MAILFILTER_VAL		0x10
#define MAILFOR_OFF		3
#define MAILFOR_VAL		0x01
#define MBFWD_OFF		4
#define MBFWD_VAL		0x40
#define MBXTDISC_OFF		4
#define MBXTDISC_VAL		0x02
#define MESSAGESERVER_OFF	13
#define MESSAGESERVER_VAL	0x20
#define MONITOR_OFF		17
#define MONITOR_VAL		0x10
#define NETROM_OFF		10
#define NETROM_VAL		0x04
#define NNTPFILTER_OFF		2
#define NNTPFILTER_VAL		0x08
#define NNTPS_OFF		2
#define NNTPS_VAL		0x40
#define NNTP_OFF		2
#define NNTP_VAL		0x20
#define NR4TDISC_OFF		10
#define NR4TDISC_VAL		0x02
#define NRS_OFF			10
#define NRS_VAL			0x08
#define NODECALL_OFF		17
#define NODECALL_VAL		0x04
#define PACKET_OFF		14
#define PACKET_VAL		0x40
#define PC100_OFF		14
#define PC100_VAL		0x20
#define PC_EC_OFF		13
#define PC_EC_VAL		0x04
#define PI_OFF			14
#define PI_VAL			0x04
#define PING_SECURE_OFF		3
#define PING_SECURE_VAL		0x10
#define PIPECMD_OFF		6
#define PIPECMD_VAL		0x80
#define POLLEDKISS_OFF		12
#define POLLEDKISS_VAL		0x02
#define POOLED_OFF		16
#define POOLED_VAL		0x01
#define POP2CLIENT_OFF		7
#define POP2CLIENT_VAL		0x04
#define POP2SERVER_OFF		7
#define POP2SERVER_VAL		0x08
#define POP3CLIENT_OFF		7
#define POP3CLIENT_VAL		0x10
#define POP3SERVER_OFF		7
#define POP3SERVER_VAL		0x20
#define POP_OFF			7
#define POP_VAL			0x80
#define PPP_OFF			6
#define PPP_VAL			0x08
#define QRZCALLB_OFF		12
#define QRZCALLB_VAL		0x20
#define RARP_OFF		9
#define RARP_VAL		0x20
#define RDATE_OFF		0
#define RDATE_VAL		0x08
#define REJECT_OFF		5
#define REJECT_VAL		0x04
#define REQSVR_OFF		8
#define REQSVR_VAL		0x40
#define RIP_OFF			9
#define RIP_VAL			0x80
#define RLINE_OFF		4
#define RLINE_VAL		0x08
#define RLOGINCLI_OFF		2
#define RLOGINCLI_VAL		0x02
#define RLOGINSERV_OFF		2
#define RLOGINSERV_VAL		0x04
#define RMAIL_OFF		8
#define RMAIL_VAL		0x80
#define ROUTESERVER_OFF		18
#define ROUTESERVER_VAL		0x80
#define RSPF_OFF		9
#define RSPF_VAL		0x40
#define RXECHO_OFF		9
#define RXECHO_VAL		0x01
#define SAMCALLB_OFF		12
#define SAMCALLB_VAL		0x10
#define SCC_OFF			14
#define SCC_VAL			0x08
#define SCREENSAVER_OFF		13
#define SCREENSAVER_VAL		0x10
#define SCRIPTING_OFF		15
#define SCRIPTING_VAL		0x04
#define SERVERS_OFF		0
#define SERVERS_VAL		0x40
#define SETPSINFO_OFF		15
#define SETPSINFO_VAL		0x08
#define SHELL_OFF		16
#define SHELL_VAL		0x08
#define SLFP_OFF		14
#define SLFP_VAL		0x02
#define SLIP_OFF		6
#define SLIP_VAL		0x04
#define SM_CURSES_OFF		15
#define SM_CURSES_VAL		0x40
#define SM_DUMB_OFF		14
#define SM_DUMB_VAL		0x01
#define SM_RAW_OFF		15
#define SM_RAW_VAL		0x80
#define SOUNDS_OFF		15
#define SOUNDS_VAL		0x10
#define SQL_OFF			1
#define SQL_VAL			0x04
#define STATS_AREA_OFF		11
#define STATS_AREA_VAL		0x10
#define STATS_FWD_OFF		11
#define STATS_FWD_VAL		0x08
#define STATS_HTTP_OFF		17
#define STATS_HTTP_VAL		0x02
#define STATS_MSG_OFF		11
#define STATS_MSG_VAL		0x20
#define STATS_OFF		11
#define STATS_VAL		0x80
#define STATS_TFC_OFF		11
#define STATS_TFC_VAL		0x04
#define STATS_USE_OFF		11
#define STATS_USE_VAL		0x40
#define STRICT_CALL_OFF		16
#define STRICT_CALL_VAL		0x02
#define STRICT_HTTPCALL_OFF	1
#define STRICT_HTTPCALL_VAL	0x20
#define TCPACCESS_OFF		7
#define TCPACCESS_VAL		0x01
#define TCPGATE_OFF		1
#define TCPGATE_VAL		0x08
#define TERMSERVER_OFF		0
#define TERMSERVER_VAL		0x02
#define TIPMAIL_OFF		6
#define TIPMAIL_VAL		0x20
#define TRACESERVER_OFF		1
#define TRACESERVER_VAL		0x01
#define TRACE_OFF		2
#define TRACE_VAL		0x01
#define TRANSLATE_OFF		8
#define TRANSLATE_VAL		0x20
#define TSCRIPTSERVER_OFF	11
#define TSCRIPTSERVER_VAL	0x01
#define TTYCALL_OFF		10
#define TTYCALL_VAL		0x40
#define TUTOR_OFF		0
#define TUTOR_VAL		0x10
#define UDPACCESS_OFF		17
#define UDPACCESS_VAL		0x01
#define UNIX_SOCKETS_OFF	15
#define UNIX_SOCKETS_VAL	0x20
#define USEPOP3_OFF		7
#define USEPOP3_VAL		0x40
#define USERLOG_OFF		3
#define USERLOG_VAL		0x02
#define USE_TZOFFSET_OFF	5
#define USE_TZOFFSET_VAL	0x01
#define VERSION_ON_FILE_OFF	15
#define VERSION_ON_FILE_VAL	0x01
#define VJCOMPRESS_OFF		6
#define VJCOMPRESS_VAL		0x02
#define WPAGES_OFF		4
#define WPAGES_VAL		0x10
#define XFWD_OFF		5
#define XFWD_VAL		0x20
#define XMODEM_OFF		6
#define XMODEM_VAL		0x10
#define XSERVER_OFF		0
#define XSERVER_VAL		0x04


#define UNUSED1_OFF		10
#define UNUSED1_VAL		0x80


#define MAPLENGTH 19


/* next to be assigned, offset 18, value 0x40 */
